cloister v0.1.0 Cloister View Source
Cloister is a consensus helper for clusters.
Link to this section Summary
Functions
Returns a specification to start this module under a supervisor.
Returns true if the hashring points to this node for the term given, false otherwise
Returns who would be chosen by a hash ring for the term
Link to this section Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Returns true if the hashring points to this node for the term given, false otherwise
Returns who would be chosen by a hash ring for the term